@@ -35,19 +35,39 @@ Returns all documents making up the blog.
 =cut
 
 sub all_documents {
-    my ($self, $bryar) = @_;
-    croak "Must pass in a Bryar object" unless UNIVERSAL::isa($bryar, "Bryar");
+    my ($self, $config) = @_;
+    croak "Must pass in a Bryar::Config object" unless UNIVERSAL::isa($config, "Bryar::Config");
     my $where = cwd;
-    chdir($bryar->{config}->datadir); # Damn you, F::F::R.
+    chdir($config->datadir); # Damn you, F::F::R.
     my @docs = map { $self->make_document($_) }
                 File::Find::Rule->file()
-                                ->name("*.txt")
-                                ->maxdepth($bryar->{config}->depth)
+                                ->name($self->entry_glob)
+                                ->maxdepth($config->depth)
                                 ->in(".");
     chdir($where);
     return @docs;
 }
 
+=head2 entry_glob
+
+Returns a glob pattern which matches blog posts. This defaults to C<*.txt>.
+
+=cut
+
+sub entry_glob { "*.txt" }
+
+=head2 id_to_file
+
+Takes a Bryar ID, converts it to a file name.
+
+=head2 file_to_id
+
+Vice versa.
+
+=cut
+
+sub id_to_file { return $_[1].".txt" }
+sub file_to_id { my $file = $_[1]; $file =~ s/.txt$//; $file; }
 
 =head2 search
 
@@ -58,17 +78,17 @@ A more advanced search for specific documents
 =cut
 
 sub search {
-    my ($self, $bryar, %params) = @_;
-    croak "Must pass in a Bryar object" unless UNIVERSAL::isa($bryar, "Bryar");
+    my ($self, $config, %params) = @_;
+    croak "Must pass in a Bryar::Config object" unless UNIVERSAL::isa($config, "Bryar::Config");
     my $was = cwd;
-    my $where = $bryar->{config}->datadir."/";
+    my $where = $config->datadir."/";
     if ($params{subblog}) { $where .= $params{subblog}; }
     chdir($where); # Damn you, F::F::R.
     
     my $find = File::Find::Rule->file();
-    if ($params{id}) { $find->name("$params{id}.txt") }
-                else { $find->name("*.txt") }
-    $find->maxdepth($bryar->{config}->depth);
+    if ($params{id}) { $find->name($self->id_to_file($params{id})) }
+                else { $find->name($self->entry_glob) }
+    $find->maxdepth($config->depth);
     if ($params{since})   { $find->mtime(">".$params{since}) }
     if ($params{before})  { $find->mtime("<".$params{before}) }
     my @docs;
@@ -103,16 +123,16 @@ sub make_document {
     my $when = (stat $file)[9];
     local $/ = "\n";
     my $who = getpwuid((stat $file)[4]);
-    $file =~ s/\.txt$//;
     my $title = <$in>;
     chomp $title;
     local $/;
     my $content = <$in>;
     close $in;
+    my $id = $self->file_to_id($file);
 
     my $comments = [];
-    $comments = [_read_comments($file, $file.".comments") ]
-        if -e $file.".comments";
+    $comments = [_read_comments($id, $id.".comments") ]
+        if -e $id.".comments";
 
     my $dir = dirname($file);
     $dir =~ s{^\./?}{};
@@ -122,7 +142,7 @@ sub make_document {
         content  => $content,
         epoch    => $when,
         author   => $who,
-        id       => $file,
+        id       => $id,
         category => $category,
         comments => $comments
     );
@@ -158,11 +178,11 @@ Records the given comment details.
 =cut
 
 sub add_comment {
-    my ($self, $bryar) = (shift, shift);
+    my ($self, $config) = (shift, shift);
     my %params = @_;
     my $file = $params{document}->id.".comments";
     # This probably fails with subblogs, but I don't use them.
-    chdir $bryar->{config}->datadir."/";
+    chdir $config->datadir."/";
     open OUT, ">> $file" or die $!;
     delete $params{document};
     s/\n/\r/g for values %params;
