@@ -12,8 +12,7 @@ Bryar::Renderer::TT - Render a blog page with Template Toolkit
 
 =head1 SYNOPSIS
 
-	$self->generate_html(...);
-	$self->generate_rss(...);
+	my ($content_type, $output) = $self->generate_html(...);
 
 =head1 DESCRIPTION
 
@@ -30,20 +29,19 @@ from the L<Bryar::Config|Bryar::Config>.
 
 =head1 METHODS
 
-=head2 generate_html
+=head2 generate
 
-    $self->generate_html($bryar, @documents)
+    $self->generate($format, $bryar, @documents)
 
-Returns a HTML page from templates and documents provided by the Bryar
-object.
+Returns a page from templates and documents provided by the Bryar object.
 
 =cut
 
 sub _tt {
     my ($class, $bryar) = @_;
     my @path = $bryar->{config}->datadir;
-    unshift @path, $bryar->{config}->datadir."/".$bryar->{arguments}->{subblog} 
-        if exists $bryar->{arguments}->{subblog};
+    unshift @path, $bryar->{config}->datadir."/".$bryar->{config}->{arguments}->{subblog} 
+        if exists $bryar->{config}->{arguments}->{subblog};
         
     @path = map { $_, $_."/templates" } @path;
     return Template->new({
@@ -74,42 +72,51 @@ EOF
     return $output;
 }
 
-sub generate_html {
-    my $class = shift;
-    $class->_tt_process("template.html", @_);
-}
+our %formats;
 
-=head2 generate_rss
+=head2 register_format
 
-    Bryar::Renderer::TT->generate_rss
+    $class->register_format($format, $filename, $content_type);
 
-This is a useful method, and should have a useful description.
+Registers a new format that Bryar is capable of producing. This can be used
+both for spitting out RSS/RDF/ATOM/whatever and for skinning the blog with
+alternate templates.
 
 =cut
 
-sub generate_rss {
-    my $class = shift;
-    $class->_tt_process("template.rss", @_);
+sub register_format {
+    my ($self, $format, $filename, $content_type) = @_;
+    $formats{$format} = [$filename, $content_type];
 }
 
+__PACKAGE__->register_format( html => "template.html", "text/html" );
+__PACKAGE__->register_format( atom => "template.atom", "application/atom+xml" );
+__PACKAGE__->register_format( xml  => "template.rss",  "application/rdf+xml");
+__PACKAGE__->register_format( rss  => "template.rss",  "application/rdf+xml");
+__PACKAGE__->register_format( rdf  => "template.rss",  "application/rdf+xml");
 
+sub generate {
+    my $class = shift;
+    my $format = shift;
+    $_[0]->config->frontend->report_error("Unknown format",
+        "Can't output a blog in format '$format', don't know what it is.")
+        if !exists $formats{$format};
 
+    my ($file, $ct) = @{$formats{$format}};
+    return ($ct, $class->_tt_process($file, @_));
+}
 
 =head1 LICENSE
 
 This module is free software, and may be distributed under the same
 terms as Perl itself.
 
-
 =head1 AUTHOR
 
 Copyright (C) 2003, Simon Cozens C<simon@kasei.com>
 
-
 =head1 SEE ALSO
 
-
-
-
+=cut
 
 1;
